@@ -115,7 +115,6 @@ void e_webcal_display_error (const gchar * title, const gchar * message,
   dialog = gtk_dialog_new ();
 
   gtk_window_set_title (GTK_WINDOW (dialog), title);
-  gtk_window_set_skip_taskbar_hint (GTK_WINDOW (dialog), TRUE);
   gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (parent));
   gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
   gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
@@ -177,7 +176,7 @@ void e_webcal_display_error (const gchar * title, const gchar * message,
 }
 
 static void select_source (ESource * source, icalcomponent_kind kind) {
-  const char * key = NULL;
+  const gchar * key = NULL;
   GConfClient * config = NULL;
   GSList * list;
 
